<?php
namespace ElementorNewsRevolutionLayouts\Widgets;

use \Elementor\Controls_Manager as Controls_Manager;
use \Elementor\Frontend;
use \Elementor\Group_Control_Border as Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow as Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography as Group_Control_Typography;
use \Elementor\Utils as Utils;
use \Elementor\Widget_Base as Widget_Base;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor News Revolution Layouts
 *
 * Elementor widget for team vision
 *
 * @since 1.0.0
 */
class News_Carousel_Revolution_Layouts extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'news-carousel-revolution-layouts';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'News Carousel Revolution Layouts', 'newsrevolutionlayoutselementor' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slideshow';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'general' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'newsrevolutionlayoutselementor' ];
	}

	/**
	 * Get post type categories.
	 */
	private function grid_get_all_post_type_categories( $post_type ) {
		$options = array();

		if ( $post_type == 'post' ) {
			$taxonomy = 'category';
		} else {
			$taxonomy = $post_type;
		}

		if ( ! empty( $taxonomy ) ) {
			// Get categories for post type.
			$terms = get_terms(
				array(
					'taxonomy'   => $taxonomy,
					'hide_empty' => false,
				)
			);
			if ( ! empty( $terms ) ) {
				foreach ( $terms as $term ) {
					if ( isset( $term ) ) {
						if ( isset( $term->slug ) && isset( $term->name ) ) {
							$options[ $term->slug ] = $term->name;
						}
					}
				}
			}
		}

		return $options;
	}

	/**
	 * Get post type categories.
	 */
	private function grid_get_all_custom_post_types() {
		$options = array();

		$args = array( '_builtin' => false );
		$post_types = get_post_types( $args, 'objects' );

		foreach ( $post_types as $post_type ) {
			if ( isset( $post_type ) ) {
					$options[ $post_type->name ] = $post_type->label;
			}
		}

		return $options;
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'newsrevolutionlayoutselementor' ),
			]
		);

		$this->add_control(
			'news_style',
			[
				'label' => esc_html__( 'Style', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1' => esc_html__('Style 1', 'newsrevolutionlayoutselementor' ),
					'style2' => esc_html__('Style 2', 'newsrevolutionlayoutselementor' ),
					'style3' => esc_html__('Style 3', 'newsrevolutionlayoutselementor' ),
				]
			]
		);

		$this->end_controls_section();

  		$this->start_controls_section(
  			'section_settings',
  			[
  				'label' => esc_html__( 'Settings', 'newsrevolutionlayoutselementor' )
  			]
		);

		$this->add_control(
			'item_show',
			[
				'label' => esc_html__( 'Number Item Show', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => '2',
				'options' => [
					'1' => '1',
					'2' => '2',
					'3' => '3',
					'4' => '4',
				]
			]
		);

		$this->add_control(
			'item_show_900',
			[
				'label' => esc_html__( 'Item Show for content between 600px to 900px', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => '2',
				'options' => [
					'1' => '1',
					'2' => '2',
					'3' => '3',
					'4' => '4',
				]
			]
		);

		$this->add_control(
			'item_show_600',
			[
				'label' => esc_html__( 'Item Show for content between 0px to 599px', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => '2',
				'label_block' => true,
				'options' => [
					'1' => '1',
					'2' => '2',
					'3' => '3',
					'4' => '4',
				]
			]
		);

		$this->add_control(
			'loop',
			[
				'label' => esc_html__( 'Loop', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'true',
				'options' => [
					'true' 		=> esc_html__( 'On', 'newsrevolutionlayoutselementor' ),
					'false' 	=> esc_html__( 'Off', 'newsrevolutionlayoutselementor' )
				]
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label' => esc_html__( 'Autoplay (ms) - ex 2000 or leave empty for default', 'newsrevolutionlayoutselementor' ),
				'label_block' => true,
				'type' => Controls_Manager::TEXT,
				'default' => '2000'
			]
		);

		$this->add_control(
			'smart_speed',
			[
				'label' => esc_html__( 'Speed (ms) - ex 2000 or leave empty for default', 'newsrevolutionlayoutselementor' ),
				'label_block' => true,
				'type' => Controls_Manager::TEXT,
				'default' => '2000'
			]
		);

		$this->add_control(
			'margin',
			[
				'label' => esc_html__( 'Margin between Items - empty to disable. Or for example: 10', 'newsrevolutionlayoutselementor' ),
				'label_block' => true,
				'type' => Controls_Manager::TEXT,
				'default' => ''
			]
		);

		$this->add_control(
			'navigation',
			[
				'label' => esc_html__( 'Navigation', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'true',
				'options' => [
					'true' 		=> esc_html__( 'Show', 'newsrevolutionlayoutselementor' ),
					'false' 	=> esc_html__( 'Hidden', 'newsrevolutionlayoutselementor' )
				]
			]
		);

		$this->add_control(
			'pagination',
			[
				'label' => esc_html__( 'Pagination', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'true',
				'options' => [
					'true' 		=> esc_html__( 'Show', 'newsrevolutionlayoutselementor' ),
					'false' 	=> esc_html__( 'Hidden', 'newsrevolutionlayoutselementor' )
				]
			]
		);

		$this->add_control(
			'rtl',
			[
				'label' => esc_html__( 'RTL', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'false',
				'options' => [
					'true' 		=> esc_html__( 'On', 'newsrevolutionlayoutselementor' ),
					'false' 	=> esc_html__( 'Off', 'newsrevolutionlayoutselementor' )
				]
			]
		);

		$this->end_controls_section();





  		$this->start_controls_section(
  			'section_query',
  			[
  				'label' => esc_html__( 'QUERY', 'newsrevolutionlayoutselementor' )
  			]
		);

		$this->add_control(
			'source',
			[
				'label' => esc_html__( 'Source', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'wp_posts',
				'options' => [
					'wp_posts' 				=> esc_html__( 'Wordpress Posts', 'newsrevolutionlayoutselementor' ),
					'post_type' 	=> esc_html__( 'Custom Posts Type', 'newsrevolutionlayoutselementor' )
				]
			]
		);

		$this->add_control(
			'posts_source',
			[
				'label' => esc_html__( 'All Posts/Sticky posts', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'all_posts',
				'options' => [
					'all_posts' 			=> esc_html__( 'All Posts', 'newsrevolutionlayoutselementor' ),
					'onlystickyposts'	=> esc_html__( 'Only Sticky Posts', 'newsrevolutionlayoutselementor' )
				],
				'condition'	=> [
					'source'	=> 'wp_posts'
				]
			]
		);

		$this->add_control(
			'posts_type',
			[
				'label' => esc_html__( 'Select Post Type Source', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => $this->grid_get_all_custom_post_types(),
				'condition'	=> [
					'source'	=> 'post_type'
				]
			]
		);

		$this->add_control(
			'categories',
			[
				'label' => esc_html__( 'Categories', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT2,
				'multiple' => true,
				'options' => $this->grid_get_all_post_type_categories('post'),
				'condition'	=> [
					'source'	=> 'wp_posts'
				]
			]
		);

		$this->add_control(
			'order',
			[
				'label' => esc_html__( 'Order', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => [
					'DESC'	=> 'DESC',
					'ASC' 	=> 'ASC'
				]
			]
		);

		$this->add_control(
			'orderby',
			[
				'label' => esc_html__( 'Order By', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => [
					'date'			=> 'Date',
					'ID' 			=> 'ID',
					'author' 		=> 'Author',
					'title' 		=> 'Title',
					'name' 			=> 'Name',
					'modified'		=> 'Modified',
					'parent' 		=> 'Parent',
					'rand' 			=> 'Rand',
					'comment_count' => 'Comments Count',
					'none' 			=> 'None'
				]
			]
		);

		$this->add_control(
			'num_posts',
			[
				'label' => esc_html__( 'Number Posts', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '10'
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_animation',
			[
				'label' => esc_html__( 'Animations', 'newsrevolutionlayoutselementor' )
			]
		);

		$this->add_control(
			'addon_animate',
			[
				'label' => esc_html__( 'Animate', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'off',
				'options' => [
					'off'	=> 'Off',
					'on' 	=> 'On'
				]
			]
		);

		$this->add_control(
			'effect',
			[
				'label' => esc_html__( 'Animate Effects', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'fade-in',
				'options' => [
							'fade-in'			=> esc_html__( 'Fade In', 'newsrevolutionlayoutselementor' ),
							'fade-in-up' 		=> esc_html__( 'fade in up', 'newsrevolutionlayoutselementor' ),
							'fade-in-down' 		=> esc_html__( 'fade in down', 'newsrevolutionlayoutselementor' ),
							'fade-in-left' 		=> esc_html__( 'fade in Left', 'newsrevolutionlayoutselementor' ),
							'fade-in-right' 	=> esc_html__( 'fade in Right', 'newsrevolutionlayoutselementor' ),
							'fade-out'			=> esc_html__( 'Fade In', 'newsrevolutionlayoutselementor' ),
							'fade-out-up' 		=> esc_html__( 'Fade Out up', 'newsrevolutionlayoutselementor' ),
							'fade-out-down' 	=> esc_html__( 'Fade Out down', 'newsrevolutionlayoutselementor' ),
							'fade-out-left' 	=> esc_html__( 'Fade Out Left', 'newsrevolutionlayoutselementor' ),
							'fade-out-right' 	=> esc_html__( 'Fade Out Right', 'newsrevolutionlayoutselementor' ),
							'bounce-in'			=> esc_html__( 'Bounce In', 'newsrevolutionlayoutselementor' ),
							'bounce-in-up' 		=> esc_html__( 'Bounce in up', 'newsrevolutionlayoutselementor' ),
							'bounce-in-down' 	=> esc_html__( 'Bounce in down', 'newsrevolutionlayoutselementor' ),
							'bounce-in-left' 	=> esc_html__( 'Bounce in Left', 'newsrevolutionlayoutselementor' ),
							'bounce-in-right' 	=> esc_html__( 'Bounce in Right', 'newsrevolutionlayoutselementor' ),
							'bounce-out'		=> esc_html__( 'Bounce In', 'newsrevolutionlayoutselementor' ),
							'bounce-out-up' 	=> esc_html__( 'Bounce Out up', 'newsrevolutionlayoutselementor' ),
							'bounce-out-down' 	=> esc_html__( 'Bounce Out down', 'newsrevolutionlayoutselementor' ),
							'bounce-out-left' 	=> esc_html__( 'Bounce Out Left', 'newsrevolutionlayoutselementor' ),
							'bounce-out-right' 	=> esc_html__( 'Bounce Out Right', 'newsrevolutionlayoutselementor' ),
							'zoom-in'			=> esc_html__( 'Zoom In', 'newsrevolutionlayoutselementor' ),
							'zoom-in-up' 		=> esc_html__( 'Zoom in up', 'newsrevolutionlayoutselementor' ),
							'zoom-in-down' 		=> esc_html__( 'Zoom in down', 'newsrevolutionlayoutselementor' ),
							'zoom-in-left' 		=> esc_html__( 'Zoom in Left', 'newsrevolutionlayoutselementor' ),
							'zoom-in-right' 	=> esc_html__( 'Zoom in Right', 'newsrevolutionlayoutselementor' ),
							'zoom-out'			=> esc_html__( 'Zoom In', 'newsrevolutionlayoutselementor' ),
							'zoom-out-up' 		=> esc_html__( 'Zoom Out up', 'newsrevolutionlayoutselementor' ),
							'zoom-out-down' 	=> esc_html__( 'Zoom Out down', 'newsrevolutionlayoutselementor' ),
							'zoom-out-left' 	=> esc_html__( 'Zoom Out Left', 'newsrevolutionlayoutselementor' ),
							'zoom-out-right' 	=> esc_html__( 'Zoom Out Right', 'newsrevolutionlayoutselementor' ),
							'flash' 			=> esc_html__( 'Flash', 'newsrevolutionlayoutselementor' ),
							'strobe'			=> esc_html__( 'Strobe', 'newsrevolutionlayoutselementor' ),
							'shake-x'			=> esc_html__( 'Shake X', 'newsrevolutionlayoutselementor' ),
							'shake-y'			=> esc_html__( 'Shake Y', 'newsrevolutionlayoutselementor' ),
							'bounce' 			=> esc_html__( 'Bounce', 'newsrevolutionlayoutselementor' ),
							'tada'				=> esc_html__( 'Tada', 'newsrevolutionlayoutselementor' ),
							'rubber-band'		=> esc_html__( 'Rubber Band', 'newsrevolutionlayoutselementor' ),
							'swing' 			=> esc_html__( 'Swing', 'newsrevolutionlayoutselementor' ),
							'spin'				=> esc_html__( 'Spin', 'newsrevolutionlayoutselementor' ),
							'spin-reverse'		=> esc_html__( 'Spin Reverse', 'newsrevolutionlayoutselementor' ),
							'slingshot'			=> esc_html__( 'Slingshot', 'newsrevolutionlayoutselementor' ),
							'slingshot-reverse'	=> esc_html__( 'Slingshot Reverse', 'newsrevolutionlayoutselementor' ),
							'wobble'			=> esc_html__( 'Wobble', 'newsrevolutionlayoutselementor' ),
							'pulse' 			=> esc_html__( 'Pulse', 'newsrevolutionlayoutselementor' ),
							'pulsate'			=> esc_html__( 'Pulsate', 'newsrevolutionlayoutselementor' ),
							'heartbeat'			=> esc_html__( 'Heartbeat', 'newsrevolutionlayoutselementor' ),
							'panic' 			=> esc_html__( 'Panic', 'newsrevolutionlayoutselementor' )
				],
				'condition'	=> [
					'addon_animate'	=> 'on'
				]
			]
		);

		$this->add_control(
			'delay',
			[
				'label' => esc_html__( 'Animate Delay (ms)', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '1000',
				'condition'	=> [
					'addon_animate'	=> 'on'
				]
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'newsrevolutionlayoutselementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'custom_style',
			[
				'label' => esc_html__( 'Custom Style', 'newsrevolutionlayoutselementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'off',
				'options' => [
					'off'	=> 'Off',
					'on' 	=> 'On'
				]
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Title Color', 'newsrevolutionlayoutselementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#333333',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->add_control(
			'link_h_color',
			[
				'label' => esc_html__( 'Link Hover Color', 'newsrevolutionlayoutselementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#258F89',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'newsrevolutionlayoutselementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#777777',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->add_control(
			'category_color',
			[
				'label' => esc_html__( 'Category Color', 'newsrevolutionlayoutselementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#258F89',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->add_control(
			'bg_category_color',
			[
				'label' => esc_html__( 'Background Category Color', 'newsrevolutionlayoutselementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => 'rgba(255,255,255,0.9)',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->add_control(
			'category_h_color',
			[
				'label' => esc_html__( 'Category Hover Color', 'newsrevolutionlayoutselementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#FFFFFF',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->add_control(
			'bg_category_h_color',
			[
				'label' => esc_html__( 'Background Category Hover Color', 'newsrevolutionlayoutselementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#258F89',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->add_control(
			'date_color',
			[
				'label' => esc_html__( 'Date\Comment Color', 'newsrevolutionlayoutselementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#777777',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->add_control(
			'nav_color',
			[
				'label' => esc_html__( 'Navigation/Pagination Carousel Color', 'newsrevolutionlayoutselementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#333333',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->add_control(
			'nav_h_color',
			[
				'label' => esc_html__( 'Navigation/Pagination Carousel Hover Color', 'newsrevolutionlayoutselementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#333333',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->add_control(
			'nav_bg_color',
			[
				'label' => esc_html__( 'Navigation Carousel Background Color', 'newsrevolutionlayoutselementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#FFFFFF',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->add_control(
			'nav_bg_h_color',
			[
				'label' => esc_html__( 'Navigation Carousel Background Hover Color', 'newsrevolutionlayoutselementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#FFFFFF',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->end_controls_section();

	}


	 /**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		static $instance = 0;
		$instance++;
		$settings = $this->get_settings_for_display();
		$columns 					= '1';
    $news_style				= esc_html($settings['news_style']);
		$item_show				= esc_html($settings['item_show']);
		$item_show_900		= esc_html($settings['item_show_900']);
		$item_show_600		= esc_html($settings['item_show_600']);
		$loop							= esc_html($settings['loop']);
		$autoplay					= esc_html($settings['autoplay']);
		$smart_speed			= esc_html($settings['smart_speed']);
		$navigation				= esc_html($settings['navigation']);
		$carousel_pagination				= esc_html($settings['pagination']);
		$margin						= esc_html($settings['margin']);
		$rtl							= esc_html($settings['rtl']);

		// Query
		$source						= esc_html($settings['source']);
		$posts_source			= esc_html($settings['posts_source']);
		$posts_type				= esc_html($settings['posts_type']);
		$categories				= '';
		if(!empty($settings['categories'])) {
			$num_cat = count($settings['categories']);
			$i = 1;
			foreach ( $settings['categories'] as $element ) {
				$categories .= $element;
				if($i != $num_cat) {
					$categories .= ',';
				}
				$i++;
			}
		}
		$categories_post_type	= '';
		$pagination					= 'off';
		$pagination_type		= 'numeric';
		$num_posts_page			= '';
		$num_posts					= esc_html($settings['num_posts']);
		$orderby						= esc_html($settings['orderby']);
		$order							= esc_html($settings['order']);

		// Style
		$custom_style					= esc_html($settings['custom_style']);
		$title_color					= esc_html($settings['title_color']);
		$text_color						= esc_html($settings['text_color']);
		$date_color						= esc_html($settings['date_color']);
		$category_color   		= esc_html($settings['category_color']);
		$bg_category_color		= esc_html($settings['bg_category_color']);
		$category_h_color			= esc_html($settings['category_h_color']);
		$bg_category_h_color	= esc_html($settings['bg_category_h_color']);
		$link_h_color					= esc_html($settings['link_h_color']);
		$nav_color					= esc_html($settings['nav_color']);
		$nav_h_color				= esc_html($settings['nav_h_color']);
		$nav_bg_color				= esc_html($settings['nav_bg_color']);
		$nav_bg_h_color			= esc_html($settings['nav_bg_h_color']);

		// Animations
		$addon_animate			= esc_html($settings['addon_animate']);
		$effect							= esc_html($settings['effect']);
		$delay							= esc_html($settings['delay']);

		wp_enqueue_style( 'animations' );
		wp_enqueue_style( 'owlcarousel' );
		wp_enqueue_style( 'animations' );
		wp_enqueue_script( 'owlcarousel' );
		wp_enqueue_script( 'news-carousel' );
		$columns_class = 'col-xs-12'; $container_class = 'newsrevolutionlayouts-np-vc-news-1-col';


			$js_class = $data_value = '';



		$container_class = $class_load_more = $class_item_load_more = $css_title = $css_text = $css_link = $css_date = $css_bg_comment = $css_comment = $css_comment_link = $css_current_pag_num = $css_bg_category_link = $css_post_bg_color = $css_category = $css_bg_category_color = '';
		$css_bg_comment = 'style="--bg-comment-color-var:#009688;"';
		if(empty($num_posts)) : $num_posts = 6; endif;

		// LOOP QUERY
		$query = newsrevolutionlayouts_query( $source,
							$posts_source,
							$posts_type,
							$categories,
							$categories_post_type,
							$order,
							$orderby,
							$pagination,
							$pagination_type,
							$num_posts,
							$num_posts_page );

		if($custom_style == 'on') :
			$css_title = 'style="color:'.esc_html($title_color).'" onMouseOver="this.style.color = \''.esc_html($link_h_color).'\';" onMouseLeave="this.style.color = \''.esc_html($title_color).'\';"';
			$css_text = 'style="color:'.esc_html($text_color).'"';
			$css_date = 'style="color:'.esc_html($date_color).'"';
      $css_comment = 'style="color:'.esc_html($date_color).'" onMouseOver="this.style.color = \''.esc_html($link_h_color).'\';" onMouseLeave="this.style.color = \''.esc_html($date_color).'\';"';
      $css_bg_category_color = 'style="color:'.esc_html($category_color).';background:'.esc_html($bg_category_color).'" onMouseOver="this.style.color = \''.esc_html($category_h_color).'\';this.style.backgroundColor = \''.esc_html($bg_category_h_color).'\';" onMouseLeave="this.style.color = \''.esc_html($category_color).'\';this.style.backgroundColor = \''.esc_html($bg_category_color).'\';"';
			$css_category = 'style="color:'.esc_html($category_color).';background:'.esc_html($bg_category_color).'" onMouseOver="this.style.color = \''.esc_html($category_h_color).'\';this.style.backgroundColor = \''.esc_html($bg_category_h_color).'\';" onMouseLeave="this.style.color = \''.esc_html($category_color).'\';this.style.backgroundColor = \''.esc_html($bg_category_color).'\';"';
		endif;

		echo '<div class="clearfix"></div>';

		$count = 0;

		echo '<div class="newsrevolutionlayouts newsrevolutionlayouts-np-vc-element-news '.esc_html($class_load_more).' newsrevolutionlayouts-np-news-'.$news_style.' newsrevolutionlayouts-np-vc-news-1-col newsrevolutionlayouts-np-vc-news-carousel-item-show-'.esc_html($item_show).' newsrevolutionlayouts-np-vc-news-carousel-item-show-900-'.esc_html($item_show_900).' newsrevolutionlayouts-np-vc-news-carousel-item-show-600-'.esc_html($item_show_600).' newsrevolutionlayouts-np-vc-element-news-'.esc_html($instance).' element-no-padding">';

		echo '<div 	'.esc_html($data_value).'
							data-newsrevolutionlayouts-news-carousel-owl-items="'.esc_html($item_show).'"
							data-newsrevolutionlayouts-news-carousel-owl-items-900="'.esc_html($item_show_900).'"
							data-newsrevolutionlayouts-news-carousel-owl-items-600="'.esc_html($item_show_600).'"
							data-newsrevolutionlayouts-news-carousel-owl-loop="'.esc_html($loop).'"
							data-newsrevolutionlayouts-news-carousel-owl-autoplay="'.esc_html($autoplay).'"
							data-newsrevolutionlayouts-news-carousel-owl-smart-speed="'.esc_html($smart_speed).'"
							data-newsrevolutionlayouts-news-carousel-owl-navigation="'.esc_html($navigation).'"
							data-newsrevolutionlayouts-news-carousel-owl-pagination="'.esc_html($carousel_pagination).'"
							data-newsrevolutionlayouts-news-carousel-owl-margin="'.esc_html($margin).'"
							data-newsrevolutionlayouts-news-carousel-owl-rtl="'.esc_html($rtl).'"
							class="newsrevolutionlayouts-np-vc-element-news-article-container newsrevolutionlayouts-np-vc-element-carousel-news newsrevolutionlayouts-np-vc-element-carousel-news-pagination-'.esc_html($pagination).' '.esc_html($js_class).'">';

		// Start Query Loop
		$loop = new \WP_Query($query);

		if($loop) :
			while ( $loop->have_posts() ) : $loop->the_post();

				$post_id = get_the_id();
				$link = get_permalink();
				if($count & 1) : $class_odd = "vc-element-post-even"; else : $class_odd = "vc-element-post-odd"; endif;

				/*************************** STYLE 1 ************************/
				if($news_style == 'style1') {
					echo '<article class="item-news first-element-news '.esc_html($columns_class).' '.esc_html($class_item_load_more).' '.esc_html($class_odd).newsrevolutionlayouts_animate_class($addon_animate,$effect,$delay).'>';
						echo '<div class="article-image">';
							echo newsrevolutionlayouts_get_thumb('newsrevolutionlayouts-header');
							echo newsrevolutionlayouts_check_post_format();
							echo '<div class="article-category">'.newsrevolutionlayouts_get_category($source,$posts_type,$css_category,$css_bg_category_color).'</div>';
						echo '</div>';
						echo '<div class="article-info">';
							echo '<div class="article-info-top">';
									echo '<div class="article-data"  '.$css_date.'><i class="far fa-calendar"></i>'.get_the_date().'</div>';
									echo '<div class="article-comments"><i class="far fa-comment-alt"  '.$css_date.'></i>'.newsrevolutionlayouts_get_num_comments($css_comment,$css_date).'</div>';
							echo '<div class="clearfix"></div></div>';
							echo '<div class="article-info-bottom">';
									echo '<h3 class="article-title"><a href="'.esc_url($link).'" '.$css_title.'>'.get_the_title().'</a></h3>';
										echo '<p class="article-excerpt" '.$css_text.'>' . newsrevolutionlayouts_get_news_excerpt(150,'on',$css_title) . '</p>';
									echo '<div class="clearfix"></div>';
							echo '</div>';
						echo '</div>';
					echo '</article>';
				}


				/*************************** STYLE 2 ************************/
				if($news_style == 'style2') {
					echo '<article class="item-news first-element-news '.esc_html($columns_class).' '.esc_html($class_item_load_more).' '.esc_html($class_odd).newsrevolutionlayouts_animate_class($addon_animate,$effect,$delay).'>';
						echo '<div class="article-image">';
							echo newsrevolutionlayouts_get_thumb('newsrevolutionlayouts-header');
							echo newsrevolutionlayouts_check_post_format();
							echo '<div class="article-category">'.newsrevolutionlayouts_get_category($source,$posts_type,$css_category,$css_bg_category_color).'</div>';
						echo '</div>';
						echo '<div class="article-info">';
							echo '<div class="article-info-top">';
									echo '<div class="article-data"  '.$css_date.'><i class="far fa-calendar"></i>'.get_the_date().'</div>';

									echo '<div class="article-comments"><i class="far fa-comment-alt"  '.$css_date.'></i>'.newsrevolutionlayouts_get_num_comments($css_comment,$css_date).'</div>';
							echo '<div class="newsrevolutionlayouts-clear"></div></div>';
							echo '<div class="article-info-bottom">';
									echo '<h3 class="article-title"><a href="'.esc_url($link).'" '.$css_title.'>'.get_the_title().'</a></h3>';
									echo '<div class="clearfix"></div>';
							echo '</div>';
						echo '</div>';
					echo '</article>';
				}



				/*************************** STYLE 3 ************************/
				if($news_style == 'style3') {
					echo '<article class="item-news first-element-news '.esc_html($columns_class).' '.esc_html($class_item_load_more).' '.esc_html($class_odd).newsrevolutionlayouts_animate_class($addon_animate,$effect,$delay).'>';
						echo '<div class="article-image">';
							echo newsrevolutionlayouts_get_thumb('newsrevolutionlayouts-header');
							echo newsrevolutionlayouts_check_post_format();
							echo '<div class="article-category">'.newsrevolutionlayouts_get_category($source,$posts_type,$css_category,$css_bg_category_color).'</div>';
						echo '</div>';
						echo '<div class="article-info">';
							echo '<div class="article-info-top">';
									echo '<div class="article-data"  '.$css_date.'><i class="far fa-calendar"></i>'.get_the_date().'</div>';
							echo '<div class="clearfix"></div></div>';
							echo '<div class="article-info-bottom">';
									echo '<h3 class="article-title"><a href="'.esc_url($link).'" '.$css_title.'>'.get_the_title().'</a></h3>';
										echo '<p class="article-excerpt" '.$css_text.'>' . newsrevolutionlayouts_get_news_excerpt(80,'on',$css_title) . '</p>';
									echo '<div class="clearfix"></div>';
							echo '</div>';
						echo '</div>';
					echo '</article>';
				}

			$count++;
			endwhile;
		endif;

		echo '</div><div class="clearfix"></div>';

		wp_reset_query();
		echo '</div>';



	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}
}
